Summary: A libpcap-based packet sniffer and logger.
Name: snort
Version: 1.7
Release: fr1
Group: System Environment/Daemons
Copyright: GPL
URL: http://www.snort.org/
Source0: http://www.snort.org/Files/%{name}-%{version}.tar.bz2
Source1: snort-stat
Source2: snortlog
Source4: snortd
Source5: snort.conf.dist
Buildroot: %{_tmppath}/%{name}-root
Requires: libpcap >= 0.4, libnet >= 1.0.2a, /sbin/service, /sbin/chkconfig
PreReq: /etc/init.d
BuildRequires: libpcap >= 0.4, libnet >= 1.0.2a, perl

%description
Snort is a libpcap-based packet sniffer/logger which can be used as a
lightweight network intrusion detection system. 
It features rules based logging and can perform protocol analysis, 
content searching/matching and can be used to detect a variety of 
attacks and probes, such as buffer overflows, stealth port scans, CGI
attacks, SMB probes, OS fingerprinting attempts, and much more. 
Snort has a real-time alerting capabilty, with alerts being sent to syslog, 
a seperate "alert" file, or as a WinPopup message via Samba's smbclient

Be sure to fetch the latest snort rules file from the ArachNIDS database
by Max Vision, or the one available from the snort.org web site.

The snortlog and snort-stat perl scripts can be used to generate statistics
from the snort syslog entries.

Snort is by default configured to listen only on eth0, and uses the default
rulesets. If this is not correct for your system, edit /etc/init.d/snortd
and /etc/snort/snort.conf

%prep
%setup -q 

%build
%configure --bindir=%{_sbindir} --sysconfdir=/etc/snort \
	--enable-smbalerts \
	--enable-flexresp
make

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}{%{_bindir},/etc/snort,/etc/init.d,/var/log/snort/archive}
%makeinstall bindir=%{buildroot}%{_sbindir}

install *-lib $RPM_BUILD_ROOT/etc/snort
install %{SOURCE1} %{buildroot}%{_bindir}
install %{SOURCE2} %{buildroot}%{_bindir}
install %{SOURCE4} %{buildroot}/etc/init.d
touch %{buildroot}/etc/snort/snort.conf

%pre
useradd -M -r -d /var/log/snort -s /bin/false -c "Snort" snort 2>/dev/null || :

%post
if [ $1 = 1 ]; then
	/sbin/chkconfig --add snortd

cat - << EOF > /etc/snort/snort.conf
# Enter your network configuration here :

var HOME_NET 192.168.23.187/32
var EXTERNAL_NET any
var DNS_SERVERS [192.168.23.1/32,192.168.23.2/32]

preprocessor defrag
preprocessor http_decode: 80 8080
preprocessor portscan: \$HOME_NET 4 3 /var/log/snort/portscan.log
preprocessor portscan-ignorehosts: \$DNS_SERVERS

# Up to date snort rules are available at the following web sites:
#   http://www.snort.org
#   http://www.whitehats.com
#
# The snort web site has documentation about how to write your own
# custom snort rules.
#
# The rules included with this distribution generate alerts based on
# on suspicious activity. Depending on your network environment, your
# security policies, and what you consider to be suspicious, some of
# these rules may either generate false positives ore may be detecting
# activity you consider to be acceptable; therefore, you are
# encouraged to comment out rules that are not applicable in your
# environment.
#
# Note that using all of the rules at the same time may lead to
# serious packet loss on slower machines. YMMV, use with caution,
# standard disclaimers apply. :)
#
# The following individuals contributed many of rules in this
# distribution.
#
# Credits:
#   Ron Gula <rgula@securitywizards.com> of Network Security Wizards
#   Martin Markgraf <martin@mail.du.gtn.com>
#   CyberPsychotic <fygrave@tigerteam.net>
#   Nick Rogness <nick@rapidnet.com>
#   Jim Forster <jforster@rapidnet.com>
#   Scott McIntyre <scott@whoi.edu>
#   Tom Vandepoel <Tom.Vandepoel@ubizen.com>                           
#
include /etc/snort/webcgi-lib
include /etc/snort/webcf-lib
include /etc/snort/webiis-lib
include /etc/snort/webfp-lib
include /etc/snort/webmisc-lib
include /etc/snort/overflow-lib
include /etc/snort/finger-lib
include /etc/snort/ftp-lib
include /etc/snort/smtp-lib
include /etc/snort/telnet-lib
include /etc/snort/misc-lib
include /etc/snort/netbios-lib
include /etc/snort/scan-lib
include /etc/snort/ddos-lib
include /etc/snort/backdoor-lib
include /etc/snort/ping-lib
include /etc/snort/rpc-lib 

# Ruleset, available (updated hourly) from:
#
#   http://dev.whitehats.com/ids/vision.rules
# include /etc/snort/vision.rules
#
# snort.conf.dist with more options is located in
# %{_docdir}/%{name}-%{version}/snort.conf.dist

EOF
fi

%preun
if [ $1 = 0 ]; then
	/sbin/service snortd stop >/dev/null 2>&1 || :
	/sbin/chkconfig --del snortd
fi

%postun
# Only if we are removing, not upgrading..
if [ "$1" -ge "1" ]; then
	/sbin/service snortd condrestart >/dev/null 2>&1 || :
else
	userdel snort 2>/dev/null || :
	groupdel snort 2>/dev/null || :
fi

%clean
rm -rf %{buildroot}

%files
%defattr(-, root, root)
%doc AUTHORS BUGS COPYING CREDITS ChangeLog NEWS README* USAGE
%doc $RPM_SOURCE_DIR/snort.conf.dist
%{_bindir}/*
%{_sbindir}/*
%attr(750, snort, snort) %dir /var/log/snort
%attr(750, snort, snort) %dir /var/log/snort/archive
%attr(750, root, root) %dir /etc/snort
%attr(640, root, root) %config /etc/snort/*-lib
%attr(640, root, root) %config(noreplace) /etc/snort/snort.conf
%attr(755, root, root) /etc/init.d/snortd

%changelog
* Thu Apr 26 2001 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Spec file cleanup and rebuilt for Red Hat 7.1.
- New init script, supports condrestart when package is upgraded.
- New config file.

* Sat Jan 06 2001 Wim Vandersmissen <wim@bofh.be>
- Updated to version 1.7
- Some minor changes to snort.conf (uses default ruleset instead of vision rules)

* Tue Jul 25 2000 Wim Vandersmissen <wim@bofh.st>
- Added some checks to find out if we're upgrading or removing the package

* Sat Jul 22 2000 Wim Vandersmissen <wim@bofh.st>
- Updated to version 1.6.3
- Fixed the user/group stuff (moved to %post)
- Added userdel/groupdel to %postun
- Automagically adds the right IP, nameservers to /etc/snort/rules.base

* Sat Jul 08 2000 Dave Wreski <dave@linuxsecurity.com>
- Updated to version 1.6.2
- Removed references to xntpd
- Fixed minor problems with snortd init script

* Fri Jul 07 2000 Dave Wreski <dave@linuxsecurity.com>
- Updated to version 1.6.1
- Added user/group snort

* Sat Jun 10 2000 Dave Wreski <dave@linuxsecurity.com>
- Added snort init.d script (snortd)
- Added Dave Dittrich's snort rules header file (ruiles.base)
- Added Dave Dittrich's wget rules fetch script (check-snort)
- Fixed permissions on /var/log/snort
- Created /var/log/snort/archive for archival of snort logs
- Added post/preun to add/remove snortd to/from rc?.d directories
- Defined configuration files as %config

* Tue Mar 28 2000 William Stearns <wstearns@pobox.com>
- Quick update to 1.6.
- Sanity checks before doing rm-rf in install and clean

* Fri Dec 10 1999 Henri Gomez <gomez@slib.fr>
- 1.5-0 Initial RPM release
